@@ -253,17 +253,13 @@ class ComponentMeta(ABCMeta):
             """
             Leafes can not add
             """
-            raise TypeError(
-                "Trying to add component {component} to Leaf".format(**locals())
-            )
+            raise TypeError(f"Trying to add component {component} to Leaf")
 
         def remove(self, component: cls):  # pylint: disable=no-self-use
             """
             Leafes can not remove
             """
-            raise TypeError(
-                "Trying to remove component {component} from Leaf".format(**locals())
-            )
+            raise TypeError(f"Trying to remove component {component} from Leaf")
 
         return cls.Subclass("Leaf", (), dict(add=add, remove=remove))
 
